==> libgii_0.8.5.orig.tar.gz: libgii-0.8.5.orig/include/ggi/internal/gii-dl.h <==
/* $Id: gii-dl.h,v 1.1.1.1 2001/05/12 23:00:14 cegger Exp $
******************************************************************************

   LibGII semi-internals. Are exported, but for source-use only.
 
   Copyright (C) 1998 Andreas Beck	[becka@ggi-project.org]
   Copyright (C) 1999 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _GGI_INTERNAL_SOURCE_H
#define _GGI_INTERNAL_SOURCE_H

#include <ggi/internal/gii.h>

/* Internal API calls
 */
__BEGIN_DECLS

int			_giiEvQueueAdd(gii_input *inp, gii_event *ev);
struct gii_input	*_giiInputAlloc(void);

__END_DECLS

#endif /* _GGI_INTERNAL_SOURCE_H */

==> libgii_1.0.1.orig.tar.gz: libgii-1.0.1/include/ggi/internal/gii-dl.h <==
/* $Id: gii-dl.h,v 1.6 2005/07/31 15:31:11 soyt Exp $
******************************************************************************

   LibGII semi-internals. Are exported, but for source-use only.

   Copyright (C) 1998 Andreas Beck	[becka@ggi-project.org]
   Copyright (C) 1999 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _GGI_INTERNAL_GII_DL_H
#define _GGI_INTERNAL_GII_DL_H

#include <ggi/internal/gii.h>

/* Internal API calls
 */
__BEGIN_DECLS

GIIAPIFUNC struct gii_input	*_giiInputAlloc(void);
GIIAPIFUNC void			_giiInputFree(struct gii_input *inp);

__END_DECLS

#endif /* _GGI_INTERNAL_GII_DL_H */
